# -*- coding: utf-8 -*-
import os
gettext = lambda s: s

SETTINGS_DIR = os.path.abspath(os.path.dirname(__file__))
PROJECT_DIR = os.path.dirname(SETTINGS_DIR)
BASE_DIR = os.path.dirname(PROJECT_DIR)

CMS_ENABLED = False

DEBUG = True

ADMINS = (
    ('Jumbo Team', 'jumbo@thundersystems.it'),
)

MANAGERS = ADMINS

SITE_ID = 1
ROOT_URLCONF = 'jmb_python_module.urls'
WSGI_APPLICATION = 'web.wsgi.application'

# i18N and L10N
TIME_ZONE = 'Europe/Rome'
LANGUAGE_CODE = 'it'
USE_I18N = True
USE_L10N = True
USE_TZ = False
LOCALE_PATHS = (
    os.path.join(PROJECT_DIR, "locale"),
)

# MEDIA AND STATIC
MEDIA_ROOT = os.path.join(BASE_DIR, "media")
MEDIA_URL = '/media/'
STATIC_ROOT = os.path.join(BASE_DIR, "static")
STATIC_URL = '/static/'
STATICFILES_DIRS = [
    os.path.join(PROJECT_DIR, "static"),
]
STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    # 'django.contrib.staticfiles.finders.DefaultStorageFinder',
]


# TEMPLATES
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(PROJECT_DIR, "templates")
        ],
        # 'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [

                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.debug',
                'django.template.context_processors.i18n',
                'django.template.context_processors.media',
                'django.template.context_processors.request',
                'django.template.context_processors.static',
                'django.template.context_processors.tz',
                'django.contrib.messages.context_processors.messages',

            ],
            'loaders': [
                'admin_tools.template_loaders.Loader',
                'django.template.loaders.filesystem.Loader',
                'django.template.loaders.app_directories.Loader',
            ]
        },
    },
]


# MIDDLEWARE
MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'corsheaders.middleware.CorsMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'jmb.core.middleware.thread_local.ThreadLocals',
]

# Python dotted path to the WSGI application used by Django's runserver.
# WSGI_APPLICATION = 'mycmsproject.wsgi.application'

INSTALLED_APPS = (
    'jmb.jadmin',
    'admin_tools',
    'admin_tools.menu',
    'django.contrib.contenttypes',
    'admin_tools.dashboard',
    'jmb.core',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # 'easy_thumbnails',
    'jmb_python_module',
    # admin docs:
    # 'django.contrib.admindocs',
    #'autocomplete_light',
    'jmb.filters',
    #'jmb.i18n',
    #'jmb.l10n',
    'rest_framework',
)


# LOGGERS
# http://docs.djangoproject.com/en/dev/topics/logging for
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'formatters': {
        'verbose': {
            'format': '%(asctime)s %(levelname)s %(module)s %(message)s'
        },
        'simple': {
            'format': '%(message)s %(levelname)s'
        },
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        },
        'console':{
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'simple'
        },
        'file': {
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '/var/log/django/jmb-default-pkg.log',
            'formatter': 'verbose'
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
        'jmb': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'DEBUG',
        }
    }
}

ALLOWED_HOSTS = ['*']
ATOMIC_REQUESTS = True
TEST_RUNNER = 'django.test.runner.DiscoverRunner'

# AUTH_USER_MODEL = 'myapp.User'
# ADMIN TOOLS SETTINGS
ADMIN_TOOLS_INDEX_DASHBOARD = 'jmb_python_module.dashboard.JumboDashboard'
ADMIN_TOOLS_MENU = 'jmb_python_module.jmenu.JumboMenu'

# hghooks: no-pyflakes no-pep8
SITE_ID = 1
DEFAULT_FROM_EMAIL = 'webmaster@thux.it'

SILENCED_SYSTEM_CHECKS = ["rest_framework.W001"]

# ## ALLAUTH
# ACCOUNT_CONFIRM_EMAIL_ON_GET = True
# LOGIN_URL = '/login/'
# ACCOUNT_EMAIL_CONFIRMATION_ANONYMOUS_REDIRECT_URL = LOGIN_URL
# ACCOUNT_EMAIL_VERIFICATION = 'mandatory'
# ACCOUNT_USERNAME_REQUIRED = False
# ACCOUNT_EMAIL_REQUIRED = True
# INFO_USER_RECIPIENT = ['sandro.dentella@gmail.com']

## Email via Sparkpost
# EMAIL_HOST = 'smtp.sparkpostmail.com'
# EMAIL_PORT = 587
# EMAIL_HOST_USER = 'SMTP_Injection'
# EMAIL_HOST_PASSWORD = ''
# EMAIL_USE_TLS = True
DEFAULT_FROM_EMAIL = 'webmaster@thux.it'
SERVER_EMAIL = 'webmaster@thux.it'
EMAIL_SUBJECT_PREFIX = '[Thux]'
